import logging
import ibmsecurity.isam.base.container_ext.volume as volume

logger = logging.getLogger(__name__)

uri = "/isam/container_ext/container"

requires_version = "10.0.7.0"
requires_model = "Appliance"


def get_all(isamAppliance, check_mode=False, force=False):
    """
    Retrieving all known deployment properties for managed containers
    ./testisam_cmd.py --hostname=${ISAM_LMI} --method=ibmsecurity.isam.base.container_ext.container.get_all
    """
    return isamAppliance.invoke_get(
        "Retrieving managed container properties",
        f"{uri}",
        requires_model=requires_model,
        requires_version=requires_version,
    )


def get(isamAppliance, container_id, check_mode=False, force=False):
    """
    Get specific configuration for a specific container
    """
    return isamAppliance.invoke_get(
        "Retrieving configuration for container",
        f"{uri}/{container_id}",
        requires_model=requires_model,
        requires_version=requires_version,
    )


def add(
    isamAppliance,
    name,
    image,
    type,
    ports,
    volumes,
    env=None,
    logging=None,
    command=None,
    args=None,
    check_mode=False,
    force=False,
    warnings=None,
):
    """
    Add a container
    """
    if force or not _check(isamAppliance, name):
        if check_mode:
            return isamAppliance.create_return_object(changed=True, warnings=warnings)
        else:
            post_data = {"name": name, "image": image, "type": type, "ports": ports}
            # Allow volume_name or value in volumes configuraiton
            # volume_name will do a lookup
            new_volumes = []
            for v in volumes:
                if v.get("value", None) is None:
                    volume_name = v.get("volume_name", None)
                    if volume_name is None:
                        new_volumes.append(v)
                    else:
                        new_value = volume.search(isamAppliance, volume_name)

                        new_volumes.append(
                            {
                                "name": v.get("name", "volume1"),
                                "value": new_value.get("data", None),
                            }
                        )
                else:
                    new_volumes.append(v)
            post_data["volumes"] = new_volumes
            if env:
                post_data["env"] = env
            if logging:
                post_data["logging"] = logging
            if command:
                post_data["command"] = command
            if args:
                post_data["args"] = args
            return isamAppliance.invoke_post(
                "Create new container",
                uri,
                post_data,
                requires_model=requires_model,
                requires_version=requires_version,
            )

    return isamAppliance.create_return_object()


def update(
    isamAppliance,
    name,
    operation=None,
    command=None,
    args=None,
    check_mode=False,
    force=False,
    warnings=None,
):
    """
    Update the pod state container deployment
    """
    container_id = search(isamAppliance, name, check_mode, force)
    container_id = container_id.get('data', None)

    if force or container_id is not None:
        if check_mode:
            return isamAppliance.create_return_object(changed=True, warnings=warnings)
        else:
            put_data = {}
            if operation:
                put_data["operation"] = operation
            if command:
                put_data["command"] = command
            if args:
                put_data["args"] = args
            return isamAppliance.invoke_put(
                "Update the pod state of a container",
                f"{uri}/{container_id}",
                put_data,
                requires_model=requires_model,
                requires_version=requires_version,
            )

    return isamAppliance.create_return_object()


def set(
    isamAppliance,
    name,
    image,
    type,
    ports,
    volumes,
    env=None,
    logging=None,
    command=None,
    args=None,
    replace=False,
    check_mode=False,
    force=False,
    warnings=None,
):
    """
    Replace or create a container
    Use replace as variable to control what will happen (in addition to force)
    """
    if not _check(isamAppliance, name):
        return add(
            isamAppliance,
            name,
            image,
            type,
            ports,
            volumes,
            env,
            logging,
            command,
            args,
            check_mode,
            force,
            warnings,
        )
    else:
        # Delete container and then add it again.

        if force or replace:
            if check_mode:
                return isamAppliance.create_return_object(changed=True, warnings=warnings)
            else:
                logger.debug(f"Replace {name}")
                delete(isamAppliance, name, check_mode, force)
                return add(
                    isamAppliance,
                    name,
                    image,
                    type,
                    ports,
                    volumes,
                    env,
                    logging,
                    command,
                    args,
                    check_mode,
                    force,
                    warnings,
                )

        return isamAppliance.create_return_object()


def delete(isamAppliance, name, check_mode=False, force=False):
    """
    Delete a container by name
    ./testisam_cmd.py --hostname=${ISAM_LMI} --method=ibmsecurity.isam.base.container_ext.container.delete --method_options="name=iag-deployment"
    """
    ret_obj = search(isamAppliance, name)
    container_id = ret_obj.get("data", None)
    if force or container_id is not None:
        if check_mode:
            return isamAppliance.create_return_object(changed=True)
        else:
            return isamAppliance.invoke_delete(
                "Delete a container",
                f"{uri}/{container_id}"
            )

    return isamAppliance.create_return_object()


def _check(isamAppliance, name):
    """
    Check if there's a container going by name
    """
    ret_obj = get_all(isamAppliance)
    for c in ret_obj["data"]:
        if c.get("name") == name:
            logger.debug(f"Container exists {name}")
            return True
    return False


def search(isamAppliance, name, check_mode=False, force=False):
    """
    Return the id of the container

    :param isamAppliance:
    :param image:
    :param check_mode:
    :param force:
    :return:
    """
    ret_obj = get_all(isamAppliance, check_mode, force)
    return_obj = isamAppliance.create_return_object()
    return_obj["data"] = None
    for obj in ret_obj["data"]:
        if obj["name"] == name:
            return_obj["data"] = obj["id"]
            return_obj["rc"] = 0
            logger.debug(f"Found id: {obj['id']} for container {name}")
            break

    return return_obj



import logging
import ibmsecurity.utilities.tools
import os.path
from ibmsecurity.utilities import tools

logger = logging.getLogger(__name__)


def get(isamAppliance, instance_id, dir_name='', recursive='yes', check_mode=False, force=False):
    """
    Retrieving the current administration pages contents of a directory.
    Parameter variables have the following behavior:
        dir_name and recursive not set => recursively list from root directory (default behavior)
        dir_name only set => list recursively from dir_name and below
        recursive set to 'no' => flat directory listing of dir_name (which defaults to root)
    """
    return isamAppliance.invoke_get("Retrieving the current administration pages root contents",
                                    "/wga/reverseproxy/{0}/management_root/{1}{2}".format(
                                        instance_id, dir_name, tools.create_query_string(recursive=recursive)))


def _check(isamAppliance, instance_id, id, name):
    ret_obj = get(isamAppliance, instance_id)

    dir_name = os.path.join(id, name)

    return _parse_id(ret_obj['data'], dir_name)


def _parse_id(contents, dir_name):
    """
    Recursively parse and find the id for a given directory

    :param contents:
    :param dir_name:
    :return id:
    """
    try:
        split_dir = dir_name.split('/', 1)
        cur_dir = split_dir[0]
        rest_dir = split_dir[1]
    except:
        rest_dir = ''
    for dir in contents:
        if dir['name'] == cur_dir and dir['type'] == 'Directory':
            if rest_dir == '':
                return dir['id']
            else:
                if len(dir['children']) == 0:
                    return None
                else:
                    return _parse_id(dir['children'], rest_dir)

    return None


def create(isamAppliance, instance_id, id, name, check_mode=False, force=False):
    """
    Creating a directory in the administration pages root

    :param isamAppliance:
    :param instance_id:
    :param id:
    :param name:
    :param check_mode:
    :param force:
    :return:
    """
    if force is True or _check(isamAppliance, instance_id, id, name) == None:
        if check_mode is True:
            return isamAppliance.create_return_object(changed=True)
        else:
            return isamAppliance.invoke_post(
                "Creating a directory in the administration pages root",
                "/wga/reverseproxy/{0}/management_root/{1}".format(instance_id, id),
                {
                    'dir_name': name,
                    'type': 'dir'
                })

    return isamAppliance.create_return_object()


def delete(isamAppliance, instance_id, id, check_mode=False, force=False):
    """
    Deleting a file or directory in the administration pages root

    :param isamAppliance:
    :param instance_id:
    :param id:
    :param name:
    :param check_mode:
    :param force:
    :return:
    """
    if force is True or _check(isamAppliance, instance_id, id, '') != None:
        if check_mode is True:
            return isamAppliance.create_return_object(changed=True)
        else:
            return isamAppliance.invoke_delete(
                "Deleting a directory in the administration pages root",
                "/wga/reverseproxy/{0}/management_root/{1}".format(instance_id, id))

    return isamAppliance.create_return_object()


def rename(isamAppliance, instance_id, id, new_name, check_mode=False, force=False):
    """
    Deleting a file or directory in the administration pages root

    :param isamAppliance:
    :param instance_id:
    :param id:
    :param name:
    :param check_mode:
    :param force:
    :return:
    """
    dir_id = None
    if force is False:
        dir_id = _check(isamAppliance, instance_id, id, '')

    if force is True or dir_id != None:
        if check_mode is True:
            return isamAppliance.create_return_object(changed=True)
        else:
            return isamAppliance.invoke_put(
                "Renaming a directory in the administration pages root",
                "/wga/reverseproxy/{0}/management_root/{1}".format(instance_id, id),
                {
                    'id': dir_id,
                    'new_name': new_name,
                    'type': 'directory'
                })

    return isamAppliance.create_return_object()


def _remove_version(contents):
    """
    Recursively parse and remove version

    :param contents:
    :return:
    """
    for obj in contents:
        try:
            del obj['version']
            if len(obj['children']) != 0:
                _remove_version(obj['children'])
        except:
            pass
    return


def compare(isamAppliance1, isamAppliance2, instance_id):
    ret_obj1 = get(isamAppliance1, instance_id)
    ret_obj2 = get(isamAppliance2, instance_id)

    _remove_version(ret_obj1['data'])
    _remove_version(ret_obj2['data'])

    return ibmsecurity.utilities.tools.json_compare(ret_obj1, ret_obj2, deleted_keys=['version'])



import logging
from ibmsecurity.utilities import tools

logger = logging.getLogger(__name__)

# URI for this module
uri = "/ldap_object"


def get(isvgAppliance, check_mode=False, force=False):
    """
    Retrieve identity user registry configuration
    """
    return isvgAppliance.invoke_get("Retrieve identity user registry configuration entries", "{0}".format(uri))


def search(isvgAppliance, name, check_mode=False, force=False):
    """
    Search for existing identity user registry configuration.
    """
    ret_obj = get(isvgAppliance)
    return_obj = isvgAppliance.create_return_object()

    for obj in ret_obj['data']:
        if 'name' in obj and obj['name'] == name:
            logger.info("Found db entry: {0}".format(obj['name']))
            return_obj['data'] = obj
            return_obj['rc'] = 0

    return return_obj


def add(isvgAppliance, hostName, port, bindDN, bindPwd, orgName, shortOrgName, dnLocation, existingLDAP, useSSL, check_mode=False, force=False):
    """
    Updating identity user registry configuration
    """
    if force is True:
        if check_mode is True:
            return isvgAppliance.create_return_object(changed=True)
        else:
            if existingLDAP == ['true']:
                # Reconfiguration does not update the database schema. It configures only the Identity Manager database details.
                action = "reconfigure"
            else:
                # Configuration updates the database schema, in addition it configures the Identity Manager database details.
                action = "configure"

            return isvgAppliance.invoke_post(
                "Configure identity data store", "{0}".format(uri),
                    {
                      "name": "Identity User Registry",
                      "hostName": hostName,
                      "port": port,
                      "bindDN": bindDN,
                      "bindPwd": bindPwd,
                      "orgName": orgName,
                      "shortOrgName": shortOrgName,
                      "dnLocation": dnLocation,
                      "action": action,
                      "useSSL": useSSL,
                      "_isNew": True,
                      "existingLDAP": existingLDAP
                    })

    return isvgAppliance.create_return_object(changed=False)


def delete(isvgAppliance, name, check_mode=False, force=False):
    """
    Un-configure identity data store
    """
    ret_obj = search(isvgAppliance, name)
    warnings = ret_obj['warnings']

    if force is True or ret_obj['data'] != {}:
        if check_mode is True:
            return isvgAppliance.create_return_object(changed=True, warnings=warnings)
        else:
            uuid = ret_obj['data']['uuid']
            return isvgAppliance.invoke_delete(
                "Un-configure identity data store", "{0}/{1}".format(uri, uuid), warnings=warnings)

    return isvgAppliance.create_return_object(warnings=warnings)


def update(isvgAppliance, hostName, port, bindDN, bindPwd, orgName, shortOrgName, dnLocation, existingLDAP, useSSL, check_mode=False, force=False):
    """
    Updating identity data store
    """
    ret_obj = get(isvgAppliance)
    warnings = ret_obj['warnings']

    # JSON payload of interest is at first (and only) position of array
    ret_obj['data'] = ret_obj['data'][0]

    uuid = ret_obj['data']['uuid']

    needs_update = False

    # Create a simple json with just the attributes
    json_data = {
        "name": "Identity User Registry",
        "uuid": uuid
    }

    if 'action' in ret_obj['data']:
        del ret_obj['data']['action']
    if 'lastmodified' in ret_obj['data']:
        del ret_obj['data']['lastmodified']
    if 'certCheckSum' in ret_obj['data']:
        del ret_obj['data']['certCheckSum']

    # mandatory attributes
    if hostName is not None:
        json_data['hostName'] = hostName
    elif 'hostName' in ret_obj['data']:
        if ret_obj['data']['hostName'] is not None:
            json_data['hostName'] = ret_obj['data']['hostName']
        else:
            del ret_obj['data']['hostName']
    if port is not None:
        json_data['port'] = port
    elif 'port' in ret_obj['data']:
        if ret_obj['data']['port'] is not None:
            json_data['port'] = ret_obj['data']['port']
        else:
            del ret_obj['data']['port']
    if bindDN is not None:
        json_data['bindDN'] = bindDN
    elif 'bindDN' in ret_obj['data']:
        if ret_obj['data']['bindDN'] is not None:
            json_data['bindDN'] = ret_obj['data']['bindDN']
        else:
            del ret_obj['data']['bindDN']
    if bindPwd is not None:
        json_data['bindPwd'] = bindPwd
    elif 'bindPwd' in ret_obj['data']:
        if ret_obj['data']['bindPwd'] is not None:
            json_data['bindPwd'] = ret_obj['data']['bindPwd']
        else:
            del ret_obj['data']['bindPwd']
    if orgName is not None:
        json_data['orgName'] = orgName
    elif 'orgName' in ret_obj['data']:
        if ret_obj['data']['orgName'] is not None:
            json_data['orgName'] = ret_obj['data']['orgName']
        else:
            del ret_obj['data']['orgName']
    if shortOrgName is not None:
        json_data['shortOrgName'] = shortOrgName
    elif 'shortOrgName' in ret_obj['data']:
        if ret_obj['data']['shortOrgName'] is not None:
            json_data['shortOrgName'] = ret_obj['data']['shortOrgName']
        else:
            del ret_obj['data']['shortOrgName']
    if dnLocation is not None:
        json_data['dnLocation'] = dnLocation
    elif 'dnLocation' in ret_obj['data']:
        if ret_obj['data']['dnLocation'] is not None:
            json_data['dnLocation'] = ret_obj['data']['dnLocation']
        else:
            del ret_obj['data']['dnLocation']
    if useSSL is not None:
        json_data['useSSL'] = useSSL
    elif 'useSSL' in ret_obj['data']:
        if ret_obj['data']['useSSL'] is not None:
            json_data['useSSL'] = ret_obj['data']['useSSL']
        else:
            del ret_obj['data']['useSSL']

    sorted_ret_obj = tools.json_sort(ret_obj['data'])
    sorted_json_data = tools.json_sort(json_data)
    logger.debug("Sorted Existing Data:{0}".format(sorted_ret_obj))
    logger.debug("Sorted Desired  Data:{0}".format(sorted_json_data))
    if sorted_ret_obj != sorted_json_data:
        json_data['_isNew'] = False
        json_data['action'] = "reconfigure"
        if existingLDAP is not None:
            json_data['existingLDAP'] = existingLDAP
        needs_update = True

    if force is True or needs_update is True:
        if check_mode is True:
            return isvgAppliance.create_return_object(changed=True)
        else:
            return isvgAppliance.invoke_put(
                "Update identity data store", "{0}/{1}".format(uri, uuid),
                json_data, warnings=warnings)

    return isvgAppliance.create_return_object(changed=False)


def set(isvgAppliance, hostName, port, bindDN, bindPwd, orgName, shortOrgName, dnLocation, existingLDAP, useSSL=False, check_mode=False, force=False):
    """
    Creating or Modifying a identity user registry configuration
    """
    name = "Identity User Registry"
    if (search(isvgAppliance, name))['data'] == {}:
        # Force the add - we already know object does not exist
        logger.info("Identity user registry {0} had no match, requesting to configure.".format(name))
        return add(isvgAppliance, hostName, port, bindDN, bindPwd, orgName, shortOrgName, dnLocation, existingLDAP, useSSL, check_mode=check_mode, force=True)
    else:
        # Update request
        logger.info("Identity user registry {0} exists, requesting to reconfigure.".format(name))
        return update(isvgAppliance, hostName, port, bindDN, bindPwd, orgName, shortOrgName, dnLocation, existingLDAP, useSSL, check_mode=check_mode, force=force)



import logging

logger = logging.getLogger(__name__)
# URI for this module
uri = "/iam/access/v8/geolocation-db"
requires_modules = None
requires_version = None


def get(isamAppliance, check_mode=False, force=False):
    """
    Get the status of the geolocation database load
    """
    return isamAppliance.invoke_get("Get the status of the geolocation database load", f"{uri}/status",
                                    requires_modules=requires_modules, requires_version=requires_version)


def cancel(isamAppliance, check_mode=False, force=False):
    """
    Cancel the most recent geolocation database load
    """
    ret_obj = get(isamAppliance)
    if force is True or ret_obj['data']['status'] == 'LOADING':
        if check_mode is True:
            return isamAppliance.create_return_object(changed=True)
        else:
            return isamAppliance.invoke_get("Cancel the most recent geolocation database load", f"{uri}/cancel",
                                            requires_modules=requires_modules, requires_version=requires_version)

    return isamAppliance.create_return_object()


def upload(isamAppliance, file=None, check_mode=False, force=False):
    """
    Load new geolocation database
    """
    warnings = ["No idempotency check for this function."]

    if check_mode is True:
        return isamAppliance.create_return_object(changed=True, warnings=warnings)
    else:
        return isamAppliance.invoke_post_files(
            "Load new geolocation database", uri,
            [
                {
                    'file_formfield': 'file',
                    'filename': file,
                    'mimetype': 'application/octet-stream'
                }
            ],
            {}, warnings=warnings, requires_modules=requires_modules, requires_version=requires_version)



import logging
import ibmsecurity.utilities.tools

logger = logging.getLogger(__name__)

requires_modules = ["wga"]
requires_version = "10.0.6.0"
# URIs for this module
acl_list_uri = "/isam/pdadmin/acllistext/v1"
show_uri = "/isam/pdadmin/aclshowext/v1"
object_list_uri = "/isam/pdadmin/aclfindext/v1"

def get_list(isamAppliance, isamUser, acl_attribute_name=None, acl_attribute_value=None, admin_domain='Default'):
    """
    Retrieve a list of ACLs using either an attribute name or value.
    """
    logger.info("ACL Name: {}".format(acl_attribute_name))
    logger.info("ACL Value: {}".format(acl_attribute_value))
    logger.info("Domain: {}".format(admin_domain))

    ret_obj = isamAppliance.invoke_post("Retrieve a list of ACLs",
                                         acl_list_uri, {
                                            "admin_id": isamUser.username,
                                            "admin_pwd": isamUser.password,
                                            "acl_attribute_name": acl_attribute_name,
                                            "acl_attribute_value": acl_attribute_value,
                                            "admin_domain": admin_domain
                                        })
    ret_obj['changed'] = False

    return ret_obj


def get(isamAppliance, isamUser, acl_name, admin_domain='Default'):
    """
    Retrieve a specific ACL
    """
    ret_obj = isamAppliance.invoke_post("Retrieve a specific ACL",
                                         show_uri, {
                                            "admin_id": isamUser.username,
                                            "admin_pwd": isamUser.password,
                                            "acl_name": acl_name,
                                            "admin_domain": admin_domain
                                        })
    ret_obj['changed'] = False

    return ret_obj


def get_object_list(isamAppliance, isamUser, object=None, acl_name=None, acl_attribute_name=None, acl_attribute_value=None,
                 admin_domain='Default'):
    """
    Retrieve a list of objects protected by a given ACL or attribute.
    """
    ret_obj = isamAppliance.invoke_post("Retrieve a list of protected objects",
                                         object_list_uri, {
                                            "admin_id": isamUser.username,
                                            "admin_pwd": isamUser.password,
                                            "object": object,
                                            "acl_name": acl_name,
                                            "acl_attribute_name": acl_attribute_name,
                                            "acl_attribute_value": acl_attribute_value,
                                            "admin_domain": admin_domain
                                        })
    ret_obj['changed'] = False

    return ret_obj


def compare(isamAppliance1, isamAppliance2, isamUser1, isamUser2, acl_attribute_name=None, acl_attribute_value=None,
            admin_domain='Default'):
    """
    Compare the list of ACLs between two appliances
    """
    ret_obj1 = get_list(isamAppliance1, isamUser1, acl_attribute_name, acl_attribute_value, admin_domain=admin_domain)
    ret_obj2 = get_list(isamAppliance2, isamUser2, acl_attribute_name, acl_attribute_value, admin_domain=admin_domain)

    return ibmsecurity.utilities.tools.json_compare(ret_obj1, ret_obj2)



import logging
import ibmsecurity.utilities.tools
from ibmsecurity.isam.web.reverse_proxy import junctions

logger = logging.getLogger(__name__)
requires_modules = ["wga"]
requires_version = "10.0.2.0"


def config(isamAppliance, instance_id, junction="/ivg", mmfa=True, check_mode=False):
    """
    IVG configuration for a reverse proxy instance

    :param isamAppliance:
    :param instance_id:
    :param junction:
    :param mmfa:
    :param check_mode:
    :return:
    """
    warnings = []
    json_data = {
        "junction": junction,
        "mmfa": mmfa
    }
    if check_mode is True:
        return isamAppliance.create_return_object(changed=True, warnings=warnings)
    else:
        return isamAppliance.invoke_post(
            "IVG configuration for a reverse proxy instance",
            "/wga/reverseproxy/{0}/verify_gateway_config".format(instance_id), json_data, warnings=warnings,
            requires_modules=requires_modules, requires_version=requires_version)

    return isamAppliance.create_return_object(warnings=warnings)



import logging
from ibmsecurity.utilities import tools

logger = logging.getLogger(__name__)

# URI for this module
uri = "/iam/access/v8/sts/modules"
requires_modules = ['federation']
requires_version = "9.0.1.0"


def get_all(isamAppliance, check_mode=False, force=False):
    """
    Retrieve a list of STS module instances
    """
    return isamAppliance.invoke_get("Retrieve a list of STS module instances", uri,
                                    requires_modules=requires_modules,
                                    requires_version=requires_version)


def search(isamAppliance, name, force=False, check_mode=False):
    """
    Search STS modules by name
    """
    ret_obj = get_all(isamAppliance)
    return_obj = isamAppliance.create_return_object()

    for obj in ret_obj['data']:
        if obj['name'] == name:
            logger.info("Found STS Module {0} id: {1}".format(name, obj['id']))
            return_obj['data'] = obj['id']
            return_obj['rc'] = 0

    return return_obj


def get(isamAppliance, name, check_mode=False, force=False):
    """
    Retrieve a specific STS module instance
    """
    ret_obj = search(isamAppliance, name=name, check_mode=check_mode, force=force)
    id = ret_obj['data']

    if id == {}:
        warnings = ["STS Module {0} had no match, skipping retrieval.".format(name)]
        return isamAppliance.create_return_object(warnings=warnings)
    else:
        return _get(isamAppliance, id)


def _get(isamAppliance, id):
    """
    Internal function to get data using "id" - used to avoid extra calls
    """
    return isamAppliance.invoke_get("Retrieve a specific STS module instance", "{0}/{1}".format(uri, id),
                                    requires_modules=requires_modules,
                                    requires_version=requires_version)


def get_types(isamAppliance, check_mode=False, force=False):
    """
    Retrieve a list of STS module types
    """
    return isamAppliance.invoke_get("Retrieve a list of STS module types", "/iam/access/v8/sts/module-types",
                                    requires_modules=requires_modules,
                                    requires_version=requires_version)



import logging

logger = logging.getLogger(__name__)


def get_all(isamAppliance):
    """
    Get all features
    """
    return isamAppliance.invoke_get("Get all features",
                                    "/authorization/features/v1")


def get_user(isamAppliance, user):
    """
    Get permitted features for user
    NOTE: Getting an unexplained error for this function, URL maybe wrong
    """
    return isamAppliance.invoke_get("Get permitted features for user",
                                    f"/authorization/features/users/{user}/v1")


def get_current(isamAppliance):
    """
    Get permitted features for current user
    """
    return isamAppliance.invoke_get("Get permitted features for current user",
                                    "/permissions/v1")
